if (FALSE) # download an example genomic data set and prepare it for analysis
snps <- eigenstrat(download_data(dirname = tempdir()))
# define a set of populations to analyze and calculate a D statistic
pops <- c("French", "Sardinian", "Han", "Papuan", "Khomani_San", "Mbuti", "Dinka")
result_d <- d(
W = pops, X = "Yoruba", Y = "Vindija", Z = "Chimp",
data = snps
)
# examine the full log output associated with the returned object
loginfo(result_d)
Run the code above in your browser using DataLab